import { Module } from "@nestjs/common";

import { AskarDynamicModule } from "@ocm-engine/askar";
import { ConfigModule } from "@nestjs/config";
import {
  agentConfig,
  agentSchema,
  authConfig,
  authSchema,
  ledgersConfig,
  ledgersSchema,
  ipfsConfig,
  ipfsSchema,
  catalogConfig,
  catalogSchema,
} from "@ocm-engine/config";
import Joi from "joi";

const validationSchema = Joi.object({
  agent: agentSchema,
  auth: authSchema,
  ledgers: ledgersSchema,
  ipfs: ipfsSchema,
  catalog: catalogSchema,
});

@Module({
  imports: [
    AskarDynamicModule.forRootAsync(),
    ConfigModule.forRoot({
      isGlobal: true,
      load: [agentConfig, authConfig, ledgersConfig, ipfsConfig, catalogConfig],
      validationSchema,
    }),
  ],
  controllers: [],
  providers: [],
})
export class AppModule {}
