import React from "react";
import { observer } from "mobx-react";
import format from "date-fns/format";
import { MessageRecordDto, MessageRecordDtoRole } from "@dashboard/engine-api";
import { Tag } from "antd";
import RecordItem from "../RecordItem";
import s from "./styles.module.scss";

interface BasicMessageItemProps {
  item: MessageRecordDto;
  onClick?: () => void;
}

const BasicMessageItem = observer(
  ({ item, onClick }: BasicMessageItemProps) => {
    return (
      <RecordItem onClick={onClick} rawData={item}>
        <div className={s.content}>
          <Tag
            color={item.role === MessageRecordDtoRole.Sender ? "blue" : "green"}
          >
            Role: {item.role}
          </Tag>{" "}
          {item.content}
        </div>

        <div className={s.createdAt}>
          {item.createdAt && format(item.createdAt, "dd.MM.yyyy HH:mm:ss")}
        </div>
      </RecordItem>
    );
  },
);

export default BasicMessageItem;
