import React, { useState } from "react";
import { observer } from "mobx-react";
import { Button, Input } from "antd";

export interface CreateMessageProps {
  onCreateMessage: (message: string) => Promise<boolean>;
}

const CreateMessage: React.FC<CreateMessageProps> = observer(
  ({ onCreateMessage }) => {
    const [text, setText] = useState("");
    const [loading, setLoading] = useState(false);

    const handleCreate = async () => {
      setLoading(true);
      try {
        const result = await onCreateMessage(text);
        if (result) {
          setText("");
        }
      } catch (e) {
        console.error(e);
      }
      setLoading(false);
    };
    return (
      <div>
        <div>Create a message</div>
        <Input.TextArea
          rows={6}
          value={text}
          onChange={(e) => {
            setText(e.target.value);
          }}
          disabled={loading}
        />
        <Button onClick={handleCreate} disabled={loading} loading={loading}>
          Send message
        </Button>
      </div>
    );
  },
);

export default CreateMessage;
