import * as React from "react";
import { useLocation, Navigate } from "react-router-dom";
import { observer } from "mobx-react";
import useGlobalAuth from "@dashboard/hooks/useGlobalAuth";
import config from "@dashboard/routes/config";
import { Spin } from "antd";

export interface RequireAuthProps {
  children: React.JSX.Element;
  restricted: boolean;
}

const RequireAuth = observer(({ children, restricted }: RequireAuthProps) => {
  const { loading, authorized } = useGlobalAuth();
  const location = useLocation();

  if (loading) {
    return <Spin />;
  }

  if ((authorized && restricted) || (!authorized && !restricted)) {
    return children;
  } else if (authorized && !restricted) {
    return <Navigate to={config.connection_list.getLink()} replace />;
  } else {
    return (
      <Navigate
        to={config.login.getLink()}
        state={{ from: location }}
        replace
      />
    );
  }
});

export default RequireAuth;
