import { useEffect, useState } from "react";
import getConfig from "@dashboard/utils/getConfig";

const LS_KEY = "token";

function isJwtValid(token: string) {
  try {
    const parts = token.split(".");
    if (parts.length !== 3) {
      throw new Error("Invalid JWT token");
    }

    const payload = JSON.parse(atob(parts[1]));

    if (!payload.exp) {
      throw new Error("JWT token does not contain expiration time");
    }

    const currentTime = Math.floor(Date.now() / 1000);
    return payload.exp > currentTime;
  } catch (e: unknown) {
    if (e instanceof Error) {
      console.error(e.message);
    }
    return false;
  }
}

const useAuth = () => {
  const [authorized, setAuthorized] = useState(false);
  const [loading, setLoading] = useState(true);

  useEffect(() => {
    if (getConfig().OCMENGINE_AUTHORIZATION) {
      setAuthorized(true);
      setLoading(false);
      return;
    }

    const lsToken = localStorage.getItem(LS_KEY);
    if (lsToken) {
      if (isJwtValid(lsToken)) {
        setAuthorized(true);
      } else {
        localStorage.removeItem(LS_KEY);
      }
    }
    setLoading(false);
  }, []);

  const updateToken = (token: string | null) => {
    if (token) {
      localStorage.setItem(LS_KEY, token);
      setAuthorized(true);
    } else {
      localStorage.removeItem(LS_KEY);
      setAuthorized(false);
    }
  };

  return {
    authorized,
    loading,
    getToken: () => localStorage.getItem(LS_KEY),
    setToken: updateToken,
  };
};

export default useAuth;
