import React, { useEffect, useState } from "react";
import { Button, Input, Select, Space } from "antd";
import examples from "./examples";
import { toast } from "react-toastify";
import s from "./forms.module.scss";

export interface CustomFormProps {
  isSendingOffer: boolean;
  isSigningJsonLd: boolean;
  onSendOffer: (doc: unknown) => void;
  onSignJsonLd: (doc: unknown) => void;
}

const selectOptions = examples.map((p) => ({
  value: p.name,
  label: p.name,
}));

const CustomForm = ({
  isSendingOffer,
  isSigningJsonLd,
  onSendOffer,
  onSignJsonLd,
}: CustomFormProps) => {
  const [selectedValue, setSelectedValue] = useState("");
  const [doc, setDoc] = useState("");
  useEffect(() => {
    const pair = examples.find((p) => p.name === selectedValue);
    if (pair) {
      setDoc(JSON.stringify(pair.doc, null, 2));
    }
  }, [selectedValue]);

  const getParsedJsonLd = () => {
    let parsed;
    try {
      parsed = JSON.parse(doc);
    } catch (e) {
      toast.error("Unable to parse JSON. Please check the document");
      throw e;
    }
    return parsed;
  };

  return (
    <div>
      <div className={s.row}>
        <Select
          style={{ width: 300 }}
          onChange={(val) => setSelectedValue(val)}
          options={selectOptions}
        />
      </div>
      <div className={s.row}>
        <Input.TextArea
          rows={12}
          value={doc}
          onChange={(e) => setDoc(e.target.value)}
        />
      </div>

      <Space direction="horizontal">
        <Button
          type="primary"
          htmlType="submit"
          disabled={isSigningJsonLd || isSendingOffer}
          loading={isSendingOffer}
          onClick={() => onSendOffer(getParsedJsonLd())}
        >
          Send JSON-LD offer
        </Button>
        <Button
          type="primary"
          htmlType="submit"
          disabled={isSigningJsonLd || isSendingOffer}
          loading={isSigningJsonLd}
          onClick={() => onSignJsonLd(getParsedJsonLd())}
        >
          Sign document
        </Button>
      </Space>
    </div>
  );
};

export default CustomForm;
