import React, { useEffect, useState } from "react";
import { observer } from "mobx-react";
import { Space } from "antd";
import Modal, { FcProps } from "@dashboard/components/Modal";
import { CredentialOfferResponseDto } from "@dashboard/engine-api";
import OfferJsonLdCredentialDialogStore from "./OfferJsonLdCredentialDialogStore";
import modalStore from "@dashboard/store/modalStore";
import Intro from "./forms/Intro";
import PrivatePersonForm from "./forms/PrivatePersonForm";
import LegalParticipantForm from "./forms/LegalParticipantForm";
import CustomForm from "./forms/CustomForm";
import s from "./styles.module.scss";

export interface OfferJsonLdCredentialDialogProps {
  connectionId: string | undefined;
  onCredentialOffered: (cred: CredentialOfferResponseDto) => void;
}

const OfferJsonLdCredentialDialog = observer(
  ({
    setTitle,
    setClassName,
    setWidth,
    onClose,
    data,
  }: FcProps<OfferJsonLdCredentialDialogProps>) => {
    const [store] = useState(
      () => new OfferJsonLdCredentialDialogStore(data.connectionId),
    );

    useEffect(() => {
      setClassName(s.modal);
      setWidth("80vw");
      if (data.connectionId) {
        setTitle("Offer JSON-LD credential to " + data.connectionId);
      } else {
        setTitle("Offer connectionless JSON-LD credential");
      }
    }, [setTitle, setClassName, setWidth, data, data.connectionId]);

    return (
      <Modal.Body className={s.body}>
        <Space direction="vertical">
          {store.formType === null && (
            <Intro
              onSelect={(value) => {
                store.formType = value;
              }}
            />
          )}
          {store.formType === "privatePerson" && (
            <PrivatePersonForm
              loading={store.offerSending}
              onSendOffer={async (formData) => {
                const offer = await store.offerPrivatePersonCreds(formData);
                if (offer) {
                  data.onCredentialOffered(offer);
                  onClose();
                }
              }}
            />
          )}
          {store.formType === "legalParticipant" && (
            <LegalParticipantForm
              loading={store.offerSending}
              onSendOffer={async (formData) => {
                const offer = await store.offerLegalParticipantCreds(formData);
                if (offer) {
                  data.onCredentialOffered(offer);
                  onClose();
                }
              }}
            />
          )}
          {store.formType === "custom" && (
            <CustomForm
              isSendingOffer={store.offerSending}
              isSigningJsonLd={store.signing}
              onSendOffer={async (doc) => {
                const offer = await store.offerCustomJsonLdCreds(doc);
                if (offer) {
                  data.onCredentialOffered(offer);
                  onClose();
                }
              }}
              onSignJsonLd={async (doc) => {
                const signedDoc = await store.signJsonLd(doc);
                if (signedDoc) {
                  modalStore.openViewJsonDialog({ data: signedDoc });
                }
              }}
            />
          )}
        </Space>
      </Modal.Body>
    );
  },
);

export default OfferJsonLdCredentialDialog;
