import React, { useEffect, useState } from "react";
import { observer } from "mobx-react";
import { Form, Input, Button } from "antd";
import api, { ConnectionRecordDto } from "@dashboard/engine-api";
import { toast } from "react-toastify";
import Modal, { FcProps } from "@dashboard/components/Modal";
import s from "./styles.module.scss";
import displayError from "@dashboard/utils/displayError";

export interface ReceiveInvitationDialogProps {
  onInvitationReceived: (connection: ConnectionRecordDto) => void;
}

const ReceiveInvitationDialog = observer(
  ({ setTitle, onClose, data }: FcProps<ReceiveInvitationDialogProps>) => {
    useEffect(() => {
      setTitle("Accept invitation");
    }, [setTitle]);

    const [loading, setLoading] = useState(false);

    const onFinish = async ({ invitation }: { invitation: string }) => {
      try {
        setLoading(true);
        const connRecord = await api.acceptInvitation({
          invitationUrl: invitation,
          shortInvitationUrl: "",
        });
        toast(`Invitation received`);
        if (connRecord) {
          data.onInvitationReceived(connRecord);
          onClose();
        }
      } catch (e: unknown) {
        displayError(e);
      }
      setLoading(false);
    };

    return (
      <Modal.Body>
        <div className={s.body}>
          <Form
            layout="vertical"
            initialValues={{
              invitation: "",
            }}
            onFinish={onFinish}
            autoComplete="off"
          >
            <Form.Item
              label="outOfBandInvitationUrl"
              name="invitation"
              rules={[{ required: true, message: "Please enter invitation!" }]}
            >
              <Input.TextArea rows={12} />
            </Form.Item>

            <div className={s.footerActions}>
              <Button type="primary" htmlType="submit" disabled={loading}>
                Accept invitation
              </Button>
              <Button
                className={s.cancelButton}
                onClick={onClose}
                disabled={loading}
              >
                Close
              </Button>
            </div>
          </Form>
        </div>
      </Modal.Body>
    );
  },
);

export default ReceiveInvitationDialog;
