import { makeAutoObservable } from "mobx";
import api from "@dashboard/engine-api";
import displayError from "@dashboard/utils/displayError";

class ConnectionCreatePageStore {
  public loading = false;
  public invitationUrl: string | null | undefined = null;
  public oob: string | null = null;
  public oobId: string | null | undefined = null;

  constructor() {
    makeAutoObservable(this);
  }

  public async createConnection() {
    this.loading = true;
    try {
      const { invitationUrl, outOfBandId } = await api.createInvitation({});
      this.invitationUrl = invitationUrl;
      this.oobId = outOfBandId;
      try {
        if (invitationUrl) {
          this.oob = JSON.stringify(
            JSON.parse(atob(invitationUrl.split("oob=")[1])),
            null,
            2,
          );
        }
      } catch (e) {
        console.warn("Failed to parse invitationUrl");
      }
    } catch (e: unknown) {
      displayError(e, "Failed to create connection invitation");
    }

    this.loading = false;
  }
}

export type { ConnectionCreatePageStore };

export default ConnectionCreatePageStore;
