import React, { useState } from "react";
import { observer } from "mobx-react";
import AuthFormStore from "./AuthFormStore";
import { Button, Form, Input, QRCode } from "antd";
import useGlobalAuth from "@dashboard/hooks/useGlobalAuth";
import s from "./styles.module.scss";

const LoginPage = observer(() => {
  const auth = useGlobalAuth();
  const [store] = useState(() => new AuthFormStore(auth.setToken));

  const handleEnterEmail = ({ email }: { email: string }) => {
    store.requestTsaAuthEmail(email);
  };

  return (
    <div className={s.registerForm}>
      <div className={s.formTitle}>
        {store.mode === "email" && "Login using trusted email"}
        {store.mode === "vc" && "Scan this QR code"}
      </div>

      {store.mode === "email" && (
        <>
          <Form
            layout="vertical"
            initialValues={{
              email: "",
            }}
            onFinish={handleEnterEmail}
            autoComplete="off"
          >
            <Form.Item
              label="Email"
              name="email"
              rules={[{ required: true, message: "Please enter email" }]}
            >
              <Input />
            </Form.Item>

            <div className={s.footerActions}>
              <Button
                type="primary"
                htmlType="submit"
                disabled={store.loading}
                loading={store.loading}
              >
                Send email
              </Button>
            </div>
          </Form>

          <br />
          <Button
            type="link"
            onClick={() => {
              store.mode = "vc";
              store.requestTsaProof();
            }}
          >
            Login using VC
          </Button>
        </>
      )}

      {store.mode === "vc" && (
        <>
          <div className={s.qrWrapper}>
            <QRCode
              status={
                store.acceptanceExpired
                  ? "expired"
                  : !store.proofUrlShort || store.loading
                  ? "loading"
                  : "active"
              }
              value={store.proofUrlShort || "loading"}
              size={400}
              icon="/assets/Vereign_Logo_ICON_BLACK.png"
            />
          </div>
          {store.acceptanceExpired && (
            <>
              <br />
              <Button
                type="link"
                onClick={() => {
                  store.requestTsaProof();
                }}
              >
                Refresh
              </Button>
            </>
          )}

          <br />
          <Button
            type="link"
            onClick={() => {
              store.mode = "email";
            }}
          >
            Login using email
          </Button>
        </>
      )}
    </div>
  );
});

export default LoginPage;
