import { makeAutoObservable, runInAction } from "mobx";
import api, {
  CreddefRecordDto,
  CredentialRecordDto,
  SchemaRecordDto,
} from "@dashboard/engine-api";
import { v4 } from "uuid";
import displayError from "@dashboard/utils/displayError";

class RegisterPageStore {
  public loading = false;
  public id = v4();
  public schemaId =
    "did:indy:bcovrin:test:FcZ4aS728oRGVdNUKVaECP/anoncreds/v0/SCHEMA/Identity/1.0";
  public schema: SchemaRecordDto | null = null;
  public creddef: CreddefRecordDto | null = null;
  public shortCredentialUrl: string | null = null;
  public credentialUrl: string | null = null;
  public credentialRecord: CredentialRecordDto | null = null;

  constructor() {
    makeAutoObservable(this);
  }

  public async initializeQr(name: string) {
    runInAction(() => (this.loading = true));
    try {
      const schema = await api.getSchemaById({ id: this.schemaId });
      const credDefs = await api.fetchCredentialDefinitions();
      let requiredCredDef = credDefs.find(
        (credDef) => credDef.schemaId === this.schemaId,
      );
      if (!requiredCredDef) {
        requiredCredDef = await api.createCredentialDefinition({
          schemaId: this.schemaId,
          tag: "Identity",
          supportRevocation: false,
        });
      }

      const { shortCredentialUrl, credentialUrl, credentialRecord } =
        await api.offerCredential({
          credentialDefinitionId: requiredCredDef.id!,
          attributes: [
            {
              name: "internal-id",
              value: this.id,
            },
            {
              name: "name",
              value: name,
            },
          ],
        });
      runInAction(() => {
        this.schema = schema;
        this.creddef = requiredCredDef!;
        this.shortCredentialUrl = shortCredentialUrl;
        this.credentialUrl = credentialUrl;
        this.credentialRecord = credentialRecord;
        this.loading = false;
      });
    } catch (e: unknown) {
      displayError(e);
      runInAction(() => (this.loading = false));
    }
  }
}

export type { RegisterPageStore };

export default RegisterPageStore;
