import { makeAutoObservable, runInAction } from "mobx";
import api from "@dashboard/engine-api";
import displayError from "@dashboard/utils/displayError";

class ResolveDidPageStore {
  public loading = false;
  public did = "";
  public resolvedData: unknown = null;

  constructor() {
    makeAutoObservable(this);
  }

  public resolve = async () => {
    runInAction(() => {
      this.loading = true;
    });
    try {
      const response = await api.resolveDid({ id: this.did });
      runInAction(() => {
        this.loading = false;
        this.resolvedData = response;
      });
    } catch (e: unknown) {
      displayError(e, "Failed resolve did");
      runInAction(() => {
        this.loading = false;
      });
    }

    this.loading = false;
  };
}

export type { ResolveDidPageStore };

export default ResolveDidPageStore;
