import {
  Body,
  Query,
  Controller,
  Delete,
  Get,
  Param,
  Post,
  UseFilters,
  UseGuards,
} from "@nestjs/common";
import { AgentAnoncredsService } from "../askar/services/agent.anoncreds.service";
import { AgentBasicMessagesService } from "../askar/services/agent.basicMessages.service";
import { AgentConnectionsService } from "../askar/services/agent.connections.service";
import { AgentCredentialsService } from "../askar/services/agent.credentials.service";
import { AgentDidsService } from "../askar/services/agent.dids.service";
import { AgentJsonldService } from "../askar/services/agent.jsonld.service";
import { AgentOobService } from "../askar/services/agent.oob.service";
import { AgentProofsService } from "../askar/services/agent.proofs.service";
import { AgentOcmService } from "../askar/services/agent.ocm.service";
import {
  CreateCredentialDefinitionRequestDto,
  OfferCredentialRequestDto,
  RequestProofDto,
  CreateSchemaRequestDto,
  MakeBasicMessageRequestDto,
  AcceptProofDto,
  IdReqDto,
  CredentialFilterDto,
  MessageFilterDto,
  ProofFilterDto,
  AcceptCredentialDto,
  CreateInvitationRequestDto,
  InvitationFilterDto,
  AcceptInvitationRequestDto,
  OfferJsonCredentialRequests,
  SignJsonCredentialRequests,
  DidRecordDto,
  RequestSenderEmailVcDto,
} from "@ocm-engine/dtos";
import { AllExceptionsHandler } from "./exception.handler";
import { DidResolutionResult } from "@credo-ts/core";
import { AuthGuard } from "./auth/auth.guard";

@UseFilters(AllExceptionsHandler)
@Controller("v1")
@UseGuards(AuthGuard)
export class RestController {
  constructor(
    private readonly agentAnoncredsService: AgentAnoncredsService,
    private readonly agentBasicMessagesService: AgentBasicMessagesService,
    private readonly agentConnectionsService: AgentConnectionsService,
    private readonly agentCredentialsService: AgentCredentialsService,
    private readonly agentDidsService: AgentDidsService,
    private readonly agentJsonldService: AgentJsonldService,
    private readonly agentOobService: AgentOobService,
    private readonly agentProofsService: AgentProofsService,
    private readonly agentOcmService: AgentOcmService,
  ) {}

  @Get("/invitations")
  async fetchInvitations(@Query() filter: InvitationFilterDto) {
    return this.agentOobService.fetchInvitations(filter);
  }

  @Post("/invitations")
  createInvitation(
    @Body() createInvitationRequestDto: CreateInvitationRequestDto,
  ) {
    return this.agentOobService.createInvitation(createInvitationRequestDto);
  }

  @Get("/invitations/:id")
  getInvitationById(@Param("id") id: string) {
    return this.agentOobService.getInvitationById(id);
  }

  @Delete("/invitations/:id")
  deleteInvitationById(@Param("id") id: string) {
    return this.agentOobService.deleteInvitationById(id);
  }

  @Post("/invitations/accept")
  async acceptInvitation(
    @Body() createInvitationDto: AcceptInvitationRequestDto,
  ) {
    const url =
      createInvitationDto.invitationUrl ||
      createInvitationDto.shortInvitationUrl;

    return this.agentOobService.acceptInvitation(url);
  }

  @Get("/connections")
  async fetchConnections() {
    return this.agentConnectionsService.fetchConnections();
  }

  @Get("/connections/:id")
  async getConnectionById(@Param("id") id: string) {
    return this.agentConnectionsService.getConnectionById(id);
  }

  @Delete("/connections/:id")
  async deleteConnectionById(@Param("id") id: string) {
    return this.agentConnectionsService.deleteConnectionById(id);
  }

  @Get("/connections/oob/:id")
  async getConnectionByOobId(@Param("id") id: string) {
    return this.agentConnectionsService.getConnectionByOobId(id);
  }

  @Post("/connections/ping/:id")
  async pingConnection(@Param("id") id: string) {
    return this.agentConnectionsService.trustPingToConnection(id);
  }

  @Post("/schemas")
  async createSchema(@Body() schemaDto: CreateSchemaRequestDto) {
    return this.agentAnoncredsService.createSchema(schemaDto);
  }

  @Post("/schemas/get-by-id")
  async getSchemaById(@Body() dto: IdReqDto) {
    return this.agentAnoncredsService.getSchemaById(dto.id);
  }

  @Get("/schemas")
  async fetchSchemas() {
    return this.agentAnoncredsService.fetchSchemas();
  }

  @Get("/definitions")
  async fetchCredentialDefinitions() {
    return this.agentAnoncredsService.fetchCredentialDefinitions();
  }

  @Post("/definitions/get-by-id")
  async getCredentialDefinitionById(@Body() dto: IdReqDto) {
    return this.agentAnoncredsService.getCredentialDefinitionById(dto.id);
  }

  @Post("/definitions")
  async createCredentialDefinition(
    @Body() credentialDefinitionDto: CreateCredentialDefinitionRequestDto,
  ) {
    return this.agentAnoncredsService.createCredentialDefinition(
      credentialDefinitionDto,
    );
  }

  @Post("/credentials/offers")
  async offerCredential(@Body() dto: OfferCredentialRequestDto) {
    return this.agentCredentialsService.offerCredential(dto);
  }

  @Post("/credentials/jsonld/offers")
  async offerJsonLdCredential(@Body() data: OfferJsonCredentialRequests) {
    return this.agentJsonldService.offerJsonLdCredential(
      data.connectionId,
      data.doc,
    );
  }

  @Post("/jsonld/sign")
  async signJsonLdCredential(@Body() data: SignJsonCredentialRequests) {
    return this.agentJsonldService.signJsonLdCredential(data.doc);
  }

  @Post("/jsonld/credentials/:cred_id/prepare-verifiable-presentation")
  async signJsonLdPresentationByCredId(@Param("cred_id") credentialId: string) {
    return this.agentJsonldService.prepareVerifiablePresentationByJsonLdCredId(
      credentialId,
    );
  }

  @Get("/credentials")
  async fetchCredentials(@Query() credentialFilterDto: CredentialFilterDto) {
    return this.agentCredentialsService.fetchCredentials(credentialFilterDto);
  }

  @Get("/credentials/:id")
  async getCredentialById(@Param("id") credentialId: string) {
    return this.agentCredentialsService.getCredentialById(credentialId);
  }

  @Get("/credentials/:id/format-data")
  async getCredentialFormatDataById(@Param("id") credentialId: string) {
    return this.agentCredentialsService.getCredentialFormatDataById(
      credentialId,
    );
  }

  @Post("/credentials/offers/accept")
  async acceptCredential(@Body() dto: AcceptCredentialDto) {
    return this.agentCredentialsService.acceptCredential(dto);
  }

  @Post("/credentials/offers/:credential_record_id/decline")
  async declineCredential(
    @Param("credential_record_id") credentialRecordId: string,
  ) {
    return this.agentCredentialsService.declineCredential(credentialRecordId);
  }

  @Delete("/credentials/:id")
  async deleteCredentialById(@Param("id") credentialId: string) {
    return this.agentCredentialsService.deleteCredentialById(credentialId);
  }

  @Post("/messages")
  async sendMessage(@Body() message: MakeBasicMessageRequestDto) {
    return this.agentBasicMessagesService.sendMessage(message);
  }

  @Get("/messages")
  async fetchBasicMessages(@Query() filter: MessageFilterDto) {
    return this.agentBasicMessagesService.fetchBasicMessages(filter);
  }

  @Delete("/messages/:id")
  async deleteBasicMessage(@Param("id") messageId: string) {
    return this.agentBasicMessagesService.deleteMessageById(messageId);
  }

  @Get("/proofs")
  async fetchProofs(@Query() proofFilterDto: ProofFilterDto) {
    return this.agentProofsService.fetchProofs(proofFilterDto);
  }

  @Get("/proofs/:proof_record_id")
  async getProofById(@Param("proof_record_id") proofRecordId: string) {
    return this.agentProofsService.getProofById(proofRecordId);
  }

  @Get("/proofs/:proof_record_id/format-data")
  async getProofFormatDataById(
    @Param("proof_record_id") proofRecordId: string,
  ) {
    return this.agentProofsService.getProofFormatDataById(proofRecordId);
  }

  @Post("/proofs/:proof_record_id/acceptance-wait")
  async proofAcceptanceWait(@Param("proof_record_id") proofRecordId: string) {
    return this.agentProofsService.proofAcceptanceWait(proofRecordId);
  }

  @Post("/proofs/request")
  async requestProof(@Body() requestProofDto: RequestProofDto) {
    return this.agentProofsService.requestProof(requestProofDto);
  }

  @Post(`/proofs/accept`)
  async acceptProof(@Body() acceptProofRequestDto: AcceptProofDto) {
    return this.agentProofsService.acceptProof(acceptProofRequestDto);
  }

  @Post("/proofs/:proof_record_id/decline")
  async declineProofRequest(@Param("proof_record_id") proofRecordId: string) {
    return this.agentProofsService.declineProofRequest(proofRecordId);
  }

  @Delete("/proofs/:proof_record_id")
  async deleteProofById(@Param("proof_record_id") proofRecordId: string) {
    return this.agentProofsService.deleteProofById(proofRecordId);
  }

  @Get("/created-dids")
  async getCreatedDids(): Promise<DidRecordDto[]> {
    return this.agentDidsService.getCreatedDids();
  }

  @Post("/resolve-did")
  async resolveDid(@Body() dto: IdReqDto): Promise<DidResolutionResult> {
    return this.agentDidsService.resolve(dto.id);
  }

  @Post("/ocm/request-sender-email-vc")
  async requestSenderEmailVC(@Body() dto: RequestSenderEmailVcDto) {
    return this.agentOcmService.requestSenderEmailVC(dto);
  }
}
