import { IsArray, IsNotEmpty, IsString, ValidateNested } from "class-validator";
import { Type } from "class-transformer";
import { OfferCredentialAttributes } from "../requests/offer.credential.request.dto";
import { BaseRecordDto } from "./base.record.dto";
import { CredentialState } from "@credo-ts/core";

export class CredentialRecordDto extends BaseRecordDto {
  @IsNotEmpty()
  @IsString()
  state: CredentialState;

  @IsString()
  connectionId?: string;

  @IsArray()
  @ValidateNested({ each: true })
  @Type(() => OfferCredentialAttributes)
  attributes?: Array<OfferCredentialAttributes>;

  tags: unknown;

  public static override fromJson(
    json: InstanceType<typeof CredentialRecordDto>,
  ) {
    const dto = new CredentialRecordDto();
    dto.id = json.id;
    dto.createdAt = json.createdAt;
    dto.updatedAt = json.updatedAt;
    dto.state = json.state;
    dto.connectionId = json.connectionId;
    dto.attributes = json.attributes;
    dto.tags = json.tags;
    return dto;
  }
}
