import { IsNotEmpty, IsString } from "class-validator";
import { BaseRecordDto } from "./base.record.dto";
import { BasicMessageRole } from "@credo-ts/core";

export class MessageRecordDto extends BaseRecordDto {
  // @example 6464b521-005a-4379-91e0-a3692b31cafd
  @IsNotEmpty()
  @IsString()
  connectionId: string;

  @IsNotEmpty()
  @IsString()
  role: BasicMessageRole;

  @IsNotEmpty()
  @IsString()
  sentTime: string;

  // @example "example-ocm-name"
  @IsString()
  from?: string;

  // @example "example-ocm-name"
  @IsString()
  to?: string;

  // @example "hello world"
  @IsNotEmpty()
  @IsString()
  content: string;

  public static override fromJson(json: InstanceType<typeof MessageRecordDto>) {
    const dto = new MessageRecordDto();
    dto.id = json.id;
    dto.createdAt = json.createdAt;
    dto.updatedAt = json.updatedAt;
    dto.connectionId = json.connectionId;
    dto.role = json.role;
    dto.sentTime = json.sentTime;
    dto.from = json.from;
    dto.to = json.to;
    dto.content = json.content;
    return dto;
  }
}
